@@ -13,7 +13,9 @@
 
 import os
 import shelve
+import cPickle
 from contextlib import closing
+from utils import Storage
 
 class DBdefval(object):
     """Placeholder type for LazyDB default return value in the event a
@@ -81,8 +83,8 @@ class Db(object):
             if not self.has(key) and touch:
                 return self.put(key, default)
             return self._db.get(key, default)
-        except KeyError:
-            raise KeyError(e)
+        except (IndexError, KeyError, cPickle.UnpicklingError):
+            return default
 
     def put(self, key, record):
         """Adds a new key,val pair into the db. This will overwrite an
@@ -150,3 +152,73 @@ class Db(object):
     def destroy(self, database):
         """Used for cleanup of arbitrary tmp databases"""
         return os.remove(database)
+
+def Orm(dbname, table):
+    db = lambda: Db(dbname)
+
+    class LazyOrm(Storage):
+
+        def __init__(self, uuid=None, **data):
+            if uuid:
+                self._uuid = uuid
+                data = data if data else self.get(uuid)
+            try:
+                for k, v in data.items():
+                    setattr(self, k, v)
+            except (AttributeError, IndexError) as e:
+                raise e
+
+        def __repr__(self):     
+            return '<LazyOrm ' + repr(dict(self)) + '>'
+
+        def save(self):
+            """save the state of the current item in the db; replace
+            existing databased item (if it exists) with this dict() repr
+            of this instance, or insert it otherwise
+            """
+            uuid = self.pop('_uuid', None)
+            uuid = self.insert(dict(self), uuid=uuid)
+            setattr(self, '_uuid', uuid)
+            return uuid
+
+        @classmethod
+        def insert(cls, item, uuid=None):
+            """
+            """
+            default = [] if uuid is None else {}
+            vals = db().get(table, default=default, touch=True)
+
+            if uuid and type(vals) is dict:
+                vals.update({uuid: item})
+            else:
+                try:
+                    vals.append(item)
+                    uuid = len(vals)-1
+                except AttributeError as e:
+                    raise AttributeError('%s: Table %s.%s is of type dict and ' \
+                                             "requires key 'uuid' for insertion." \
+                                             % (e, db._name, table))
+            vals = db().put(table, vals)       
+            return uuid
+
+        @classmethod
+        def getall(cls, uuids=all, default=DBdefval):
+            vals = db().get(table, default=default)
+            if uuids is not all:
+                if type(vals) is dict:                    
+                    vals = dict(filter(lambda k, v: k in uuids, vals.items()))
+                else:
+                    vals = [v for i, v in enumerate(vals) if i in uuids]
+            return vals
+
+        @classmethod
+        def get(cls, uuid, default=DBdefval):
+            """
+            """
+            vals = cls.getall()
+            try:
+                return vals[uuid]
+            except (KeyError, IndexError):
+                return default
+
+    return LazyOrm
